@@ -20,10 +20,10 @@
 #
 # You should have received a copy of the GNU Library General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
-$SCRIPTSDIR = "/opt/kde/share/apps/knetworkconf/backends";
+$SCRIPTSDIR = "";
 if ($SCRIPTSDIR =~ /^@scriptsdir[@]/){
 
     $SCRIPTSDIR = ".";
@@ -1788,41 +1788,3 @@ sub gst_parse_pppconf_re
     return $1;
   }
 }
-
-sub gst_parse_confd_net
-{
-  my ($file, $key) = @_;
-  my ($str, $contents, $i);
-
-  $contents = &gst_file_buffer_load ($file);
-
-  for ($i = 0; $i <= scalar (@$contents); $i++)
-  {
-    # search for key
-    if ($$contents[$i] =~ /^$key[ \t]*=[ \t]*\(/)
-    {
-      # contents can be multiline,
-      # just get the first value
-      do {
-        $$contents[$i] =~ /\"([^\"]*)\"/;
-        $str = $1;
-        $i++;
-      } while (!$str);
-    }
-  }
-
-  return $str;
-}
-
-sub gst_parse_confd_net_re
-{
-  my ($file, $key, $re) = @_;
-  my ($str);
-
-  $str = &gst_parse_confd_net ($file, $key);
-
-  if ($str =~ /$re/i)
-  {
-    return $1;
-  }
-}
